@@ -28,10 +28,10 @@
 #include <tqpopupmenu.h>
 #include <tqapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
-#include <kaction.h>
+#include <tdemessagebox.h>
+#include <tdeaction.h>
 #include <kstdaction.h>
 #include <kdebug.h>
 #include <kinputdialog.h>
@@ -59,7 +59,7 @@ void MLabel::paintEvent( TQPaintEvent *pe )
 	setPaletteBackgroundColor( TQColor(r, g, b) );
 }
 
-MListView::MListView( TQWidget *parent ) : KListView( parent )
+MListView::MListView( TQWidget *parent ) : TDEListView( parent )
 {
 }
 
@@ -70,7 +70,7 @@ void MListView::resizeEvent( TQResizeEvent *rev )
 	setColumnWidth(1, width-90);  /* title */
 	setColumnWidth(2, 50);  /* duration */
 
-	KListView::resizeEvent(rev);
+	TDEListView::resizeEvent(rev);
 }
 
 Disc::Disc( TQWidget* parent, TQObject *objParent, const char *name ) : KaffeineInput(objParent , name)
@@ -113,8 +113,8 @@ Disc::Disc( TQWidget* parent, TQObject *objParent, const char *name ) : Kaffeine
 	h1->addWidget( ripBtn );
 	vb->addLayout( h1 );
 
-	cdBtn->setIconSet( KGlobal::iconLoader()->loadIconSet("cdaudio_unmount", KIcon::Toolbar) );
-	ripBtn->setIconSet( KGlobal::iconLoader()->loadIconSet("kilogram", KIcon::Toolbar) );
+	cdBtn->setIconSet( TDEGlobal::iconLoader()->loadIconSet("media-optical-cdaudio", TDEIcon::Toolbar) );
+	ripBtn->setIconSet( TDEGlobal::iconLoader()->loadIconSet("kilogram", TDEIcon::Toolbar) );
 
 	connect( cdBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(startCD()) );
 	connect( ripBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(startRIP()) );
@@ -160,7 +160,7 @@ Disc::Disc( TQWidget* parent, TQObject *objParent, const char *name ) : Kaffeine
 	enc->setTextLabel( i18n("Encode...") );
 	enc->setTextPosition( TQToolButton::Under );
 	enc->setUsesTextLabel( true );
-	enc->setIconSet( KGlobal::iconLoader()->loadIconSet("kilogram", KIcon::Small) );
+	enc->setIconSet( TDEGlobal::iconLoader()->loadIconSet("kilogram", TDEIcon::Small) );
 	enc->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
 	connect( enc, TQT_SIGNAL(clicked()), this, TQT_SLOT(encode()) );
 	vb->addWidget( encodeWidget );
@@ -180,7 +180,7 @@ Disc::Disc( TQWidget* parent, TQObject *objParent, const char *name ) : Kaffeine
 	setXMLFile("kaffeinedisc.rc");
 	setupActions();
 
-	loadConfig( KGlobal::config() );
+	loadConfig( TDEGlobal::config() );
 
 	para = NULL;
 	trackCurrent = 0;
@@ -205,13 +205,13 @@ void Disc::getTargets( TQStringList &uiNames, TQStringList &iconNames, TQStringL
 	iconNames.append( "kilogram" );
 	targetNames.append( "DISC_RIP" );
 	uiNames.append( i18n("Play Audio CD") );
-	iconNames.append( "cdaudio_unmount" );
+	iconNames.append( "media-optical-cdaudio" );
 	targetNames.append( "DISC_CDDA" );
 	uiNames.append( i18n("Play DVD") );
-	iconNames.append( "dvd_unmount" );
+	iconNames.append( "media-optical-dvd" );
 	targetNames.append( "DISC_DVD" );
 	uiNames.append( i18n("Play VCD") );
-	iconNames.append( "cdrom_unmount" );
+	iconNames.append( "media-optical-cdrom" );
 	targetNames.append( "DISC_VCD" );
 }
 
@@ -237,7 +237,7 @@ bool Disc::execTarget( const TQString &target )
 	return false;
 }
 
-void Disc::loadConfig( KConfig* config )
+void Disc::loadConfig( TDEConfig* config )
 {
 	TQValueList<int> sl;
 
@@ -248,7 +248,7 @@ void Disc::loadConfig( KConfig* config )
 
 void Disc::saveConfig()
 {
-	KConfig* config = KGlobal::config();
+	TDEConfig* config = TDEGlobal::config();
 
 	config->setGroup("Disc");
 	config->writeEntry( "SplitSizes", split->sizes() );
@@ -266,9 +266,9 @@ TQWidget* Disc::inputMainWidget()
 
 void Disc::setupActions()
 {
-	new KAction(i18n("Open &DVD"), "dvd_unmount", 0, this, TQT_SLOT(startDVD()), actionCollection(), "file_open_dvd");
-	new KAction(i18n("Open &VCD"), "cdrom_unmount", 0, this, TQT_SLOT(startVCD()), actionCollection(), "file_open_vcd");
-	new KAction(i18n("Open &Audio-CD"), "cdaudio_unmount", 0, this, TQT_SLOT(startCD()), actionCollection(), "file_open_audiocd");
+	new TDEAction(i18n("Open &DVD"), "media-optical-dvd", 0, this, TQT_SLOT(startDVD()), actionCollection(), "file_open_dvd");
+	new TDEAction(i18n("Open &VCD"), "media-optical-cdrom", 0, this, TQT_SLOT(startVCD()), actionCollection(), "file_open_vcd");
+	new TDEAction(i18n("Open &Audio-CD"), "media-optical-cdaudio", 0, this, TQT_SLOT(startCD()), actionCollection(), "file_open_audiocd");
 }
 
 void Disc::playerStopped()
@@ -392,7 +392,7 @@ void Disc::startCD( const TQString &device, bool rip )
 	bool init=false;
 	TQValueList<int> qvl;
 	int i;
-	KListViewItem *it;
+	TDEListViewItem *it;
 	MRL mrl;
 	TQStringList dcopList, devList;
 	bool ok=false;
@@ -463,7 +463,7 @@ void Disc::startCD( const TQString &device, bool rip )
 			artistLab->setText( cddb->artist() );
 			albumLab->setText( cddb->title() );
 			for ( i=0; i<para->getTracks(); i++ ) {
-				it = new KListViewItem( list, TQString().sprintf("%02d", i+1), cddb->track( i ), para->trackTime(i) );
+				it = new TDEListViewItem( list, TQString().sprintf("%02d", i+1), cddb->track( i ), para->trackTime(i) );
 				if ( i==0 ) {
 					mrl.setURL( TQString("cdda://%1/1").arg( currentDevice ) );
 					mrl.setTitle( cddb->track(i) );
@@ -479,7 +479,7 @@ void Disc::startCD( const TQString &device, bool rip )
 				artistLab->setText( cddb->artist() );
 				albumLab->setText( cddb->title() );
 				for ( i=0; i<para->getTracks(); i++ ) {
-					it = new KListViewItem( list, TQString().sprintf("%02d", i+1), cddb->track( i ), para->trackTime(i) );
+					it = new TDEListViewItem( list, TQString().sprintf("%02d", i+1), cddb->track( i ), para->trackTime(i) );
 					if ( i==0 ) {
 						mrl.setURL( TQString("cdda://%1/1").arg( currentDevice ) );
 						mrl.setTitle( cddb->track(i) );
@@ -493,7 +493,7 @@ void Disc::startCD( const TQString &device, bool rip )
 				artistLab->setText( i18n("Unknown") );
 				albumLab->setText( i18n("Unknown") );
 				for ( i=0; i<para->getTracks(); i++ ) {
-					it = new KListViewItem( list, TQString().sprintf("%02d", i+1), i18n("Track")+TQString().sprintf("%02d", i+1), para->trackTime(i) );
+					it = new TDEListViewItem( list, TQString().sprintf("%02d", i+1), i18n("Track")+TQString().sprintf("%02d", i+1), para->trackTime(i) );
 					if ( i==0 ) {
 						mrl.setURL( TQString("cdda://%1/1").arg( currentDevice ) );
 						mrl.setTitle( i18n("Track")+TQString().sprintf("%02d", i+1) );
@@ -544,7 +544,8 @@ void Disc::startDVD( const TQString &device )
 					devList.append( dcopList[i+5] );
 				}
 				else if ( dcopList[i+10]=="media/cdrom_mounted"
-				|| dcopList[i+10]=="media/cdwriter_mounted"
+				|| dcopList[i+10]=="media/cd-r_mounted"
+				|| dcopList[i+10]=="media/cd-rw_mounted"
 				|| dcopList[i+10]=="media/dvd_mounted" ) {
 					if ( TQFile::exists(dcopList[i+6]+"/video_ts") || TQFile::exists(dcopList[i+6]+"/VIDEO_TS") )
 						devList.append( dcopList[i+5] );
